@@ -35,34 +35,43 @@ ellipse <- function(x,y,covmat,alpha=0.05,n=50){
 
 # x = matrix with columns X, sX, Y, sY, rXY
 scatterplot <- function(x,xlim=NA,ylim=NA,alpha=0.05,
-                        show.numbers=FALSE,show.ellipses=TRUE,
-                        ellipse.col=grDevices::rgb(0,1,0,0.5),
-                        a=NA,b=NA,line.col='red',lwd=2,
-                        new.plot=TRUE,...){
+                        show.numbers=FALSE,show.ellipses=1,levels=NA,
+                        ellipse.col=c("#00FF0080","#FF000080"),a=NA,
+                        b=NA,line.col='red',lwd=2, new.plot=TRUE,
+                        empty=FALSE,...){
     colnames(x) <- c('X','sX','Y','sY','rXY')
     if (any(is.na(xlim))) xlim <- get.limits(x[,'X'],x[,'sX'])
     if (any(is.na(ylim))) ylim <- get.limits(x[,'Y'],x[,'sY'])
     if (new.plot) graphics::plot(xlim,ylim,type='n',xlab='',ylab='')
+    if (new.plot & empty) return()
     if (!is.na(a) & !is.na(b)){
         graphics::lines(xlim,a+b*xlim,col=line.col,lwd=lwd)
     }
     ns <- nrow(x)
-    if (show.ellipses){
+    x0 <- x[,'X']
+    y0 <- x[,'Y']
+    if (show.ellipses==0){
+        if (show.numbers) graphics::text(x0,y0,1:ns,...)
+        else graphics::points(x0,y0,...)
+    } else if (show.ellipses==1){
+        ellipse.cols <- set.ellipse.colours(ns=ns,levels=levels,col=ellipse.col)
         for (i in 1:ns){
             if (!any(is.na(x[i,]))){
-                x0 <- x[i,'X']
-                y0 <- x[i,'Y']
                 covmat <- cor2cov2(x[i,'sX'],x[i,'sY'],x[i,'rXY'])
-                ell <- ellipse(x0,y0,covmat,alpha=alpha)
-                graphics::polygon(ell,col=ellipse.col)
-                graphics::points(x0,y0,pch=19,cex=0.25)
-                if (show.numbers) { graphics::text(x0,y0,i) }
+                ell <- ellipse(x0[i],y0[i],covmat,alpha=alpha)
+                graphics::polygon(ell,col=ellipse.cols[i])
+                if (show.numbers) graphics::text(x0[i],y0[i],i)
+                else graphics::points(x0[i],y0[i],pch=19,cex=0.25)
             }
         }
+        colourbar(z=levels,col=ellipse.col)
     } else {
-        x0 <- x[,'X']
-        y0 <- x[,'Y']
-        graphics::points(x0,y0,...)
-        if (show.numbers) { graphics::text(x0,y0,1:ns) }
+        if (show.numbers) graphics::text(x0,y0,1:ns,adj=c(0,1))
+        else graphics::points(x0,y0,pch=19,cex=0.5)
+        fact <- stats::qnorm(1-alpha/2)
+        dx <- fact*x[,'sX']
+        dy <- fact*x[,'sY']
+        graphics::arrows(x0,y0-dy,x0,y0+dy,code=3,angle=90,length=0.05)
+        graphics::arrows(x0-dx,y0,x0+dx,y0,code=3,angle=90,length=0.05)
     }
 }
