@@ -18,13 +18,36 @@
 #'     legend in which the peak fitting results are to be displayed.
 #' @param log take the logs of the data before applying the mixture
 #'     model?
+#' @param alpha cutoff value for confidence intervals
 #' @param ... optional arguments (not used)
-#' @return a list with the following items: \describe{ \item{peaks}{a
-#'     vector of peak locations} \item{props}{a vector of peak
-#'     proportions} \item{peaks.err}{the standard errors of the peak
-#'     locations} \item{props.err}{the standard errors of the peak
-#'     proportions} \item{legend}{a vector of text expressions to be
-#'     used in a figure legend} }
+#' @return returns a list with the following items:
+#'
+#' \describe{
+#'
+#' \item{peaks}{a \code{3 x k} matrix with the following rows:
+#'
+#' \code{t}: the ages of the \code{k} peaks
+#'
+#' \code{s[t]}: the estimated uncertainties of \code{t}
+#'
+#' \code{ci[t]}: the \eqn{100(1-\alpha/2)\%} confidence interval for
+#' \code{t}}
+#'
+#' \item{props}{a \code{2 x k} matrix with the following rows:
+#'
+#' \code{p}: the proportions of the \code{k} peaks
+#'
+#' \code{s[p]}: the estimated uncertainties of \code{p}}
+#'
+#' \item{L}{the log-likelihood of the fit}
+#'
+#' \item{tfact}{the \eqn{100(1-\alpha/2)\%} percentile of the
+#' t-distribution with \eqn{(n-2k+1)} degrees of freedom}
+#'
+#' \item{legend}{a vector of text expressions to be used in a figure
+#'     legend}
+#'
+#' }
 #' @references Galbraith, R.F. and Laslett, G.M., 1993. Statistical
 #'     models for mixed fission track ages. Nuclear tracks and
 #'     radiation measurements, 21(4), pp.459-470.
@@ -36,39 +59,41 @@
 peakfit <- function(x,...){ UseMethod("peakfit",x) }
 #' @rdname peakfit
 #' @export
-peakfit.default <- function(x,k='auto',sigdig=2,log=TRUE,...){
+peakfit.default <- function(x,k='auto',sigdig=2,log=TRUE,alpha=0.05,...){
     if (k<1) return(NULL)
     if (log) {
         x[,2] <- x[,2]/x[,1]
         x[,1] <- log(x[,1])
     }
     if (identical(k,'min')) {
-        out <- min_age_model(x,sigdig=sigdig)
+        out <- min_age_model(x,sigdig=sigdig,alpha=alpha)
     } else if (identical(k,'auto')) {
-        out <- normal.mixtures(x,k=BIC_fit(x,5),sigdig=sigdig,...)
+        out <- normal.mixtures(x,k=BIC_fit(x,5),sigdig=sigdig,alpha=alpha,...)
     } else {
-        out <- normal.mixtures(x,k,sigdig=sigdig,...)
+        out <- normal.mixtures(x,k,sigdig=sigdig,alpha=alpha,...)
     }
     if (log) {
-        out$peaks <- exp(out$peaks)
-        out$peaks.err <- out$peaks * out$peaks.err
+        out$peaks['t',] <- exp(out$peaks['t',])
+        out$peaks['s[t]',] <- out$peaks['t',] * out$peaks['s[t]',]
+        out$peaks['ci[t]',] <- out$peaks['t',] * out$peaks['ci[t]',]
     }
     out$legend <- peaks2legend(out,sigdig=sigdig,k=k)
     out
 }
 #' @rdname peakfit
 #' @export
-peakfit.fissiontracks <- function(x,k=1,exterr=TRUE,sigdig=2,log=TRUE,...){
+peakfit.fissiontracks <- function(x,k=1,exterr=TRUE,sigdig=2,
+                                  log=TRUE,alpha=0.05,...){
     out <- NULL
     if (k == 0) return(out)
     if (identical(k,'auto')) k <- BIC_fit(x,5,log=log)
     if (x$format == 1 & !identical(k,'min')){
-        out <- binomial.mixtures(x,k,exterr=exterr,...)
+        out <- binomial.mixtures(x,k,exterr=exterr,alpha=alpha,...)
     }  else if (x$format == 3){
-        out <- ages2peaks(x,k,log=log)
+        out <- ages2peaks(x,k,log=log,alpha=alpha)
     } else {
         out <- peakfit_helper(x,k=k,sigdig=sigdig,log=log,
-                              exterr=exterr,...)
+                              exterr=exterr,alpha=alpha,...)
     }
     out$legend <- peaks2legend(out,sigdig=sigdig,k=k)
     out
@@ -95,10 +120,10 @@ peakfit.fissiontracks <- function(x,k=1,exterr=TRUE,sigdig=2,log=TRUE,...){
 #' @export
 peakfit.UPb <- function(x,k=1,type=4,cutoff.76=1100,
                         cutoff.disc=c(-15,5),exterr=TRUE,
-                        sigdig=2,log=TRUE,...){
+                        sigdig=2,log=TRUE,alpha=0.05,...){
     peakfit_helper(x,k=k,type=type,cutoff.76=cutoff.76,
                    cutoff.disc=cutoff.disc,exterr=exterr,
-                   sigdig=sigdig,log=log,...)
+                   sigdig=sigdig,log=log,alpha=alpha,...)
 }
 #' @param i2i `isochron to intercept': calculates the initial
 #'     (aka `inherited', `excess', or `common') \eqn{^{40}}Ar/\eqn{^{36}}Ar,
@@ -111,58 +136,75 @@ peakfit.UPb <- function(x,k=1,type=4,cutoff.76=1100,
 #'     \code{i2i} to \code{TRUE} applies a detrital Th-correction.
 #' @rdname peakfit
 #' @export
-peakfit.PbPb <- function(x,k=1,exterr=TRUE,sigdig=2,log=TRUE,i2i=TRUE,...){
-    peakfit_helper(x,k=k,exterr=exterr,sigdig=sigdig,log=log,i2i=i2i,...)
+peakfit.PbPb <- function(x,k=1,exterr=TRUE,sigdig=2,
+                         log=TRUE,i2i=TRUE,alpha=0.05,...){
+    peakfit_helper(x,k=k,exterr=exterr,sigdig=sigdig,
+                   log=log,i2i=i2i,alpha=alpha,...)
 }
 #' @rdname peakfit
 #' @export
-peakfit.ArAr <- function(x,k=1,exterr=TRUE,sigdig=2,log=TRUE,i2i=FALSE,...){
-    peakfit_helper(x,k=k,exterr=exterr,sigdig=sigdig,log=log,i2i=i2i,...)
+peakfit.ArAr <- function(x,k=1,exterr=TRUE,sigdig=2,
+                         log=TRUE,i2i=FALSE,alpha=0.05,...){
+    peakfit_helper(x,k=k,exterr=exterr,sigdig=sigdig,
+                   log=log,i2i=i2i,alpha=alpha,...)
 }
 #' @rdname peakfit
 #' @export
-peakfit.ReOs <- function(x,k=1,exterr=TRUE,sigdig=2,log=TRUE,i2i=TRUE,...){
-    peakfit_helper(x,k=k,exterr=exterr,sigdig=sigdig,log=log,i2i=i2i,...)
+peakfit.ReOs <- function(x,k=1,exterr=TRUE,sigdig=2,
+                         log=TRUE,i2i=TRUE,alpha=0.05,...){
+    peakfit_helper(x,k=k,exterr=exterr,sigdig=sigdig,
+                   log=log,i2i=i2i,alpha=alpha,...)
 }
 #' @rdname peakfit
 #' @export
-peakfit.SmNd <- function(x,k=1,exterr=TRUE,sigdig=2,log=TRUE,i2i=TRUE,...){
-    peakfit_helper(x,k=k,exterr=exterr,sigdig=sigdig,log=log,i2i=i2i,...)
+peakfit.SmNd <- function(x,k=1,exterr=TRUE,sigdig=2,
+                         log=TRUE,i2i=TRUE,alpha=0.05,...){
+    peakfit_helper(x,k=k,exterr=exterr,sigdig=sigdig,
+                   log=log,i2i=i2i,alpha=alpha,...)
 }
 #' @rdname peakfit
 #' @export
-peakfit.RbSr <- function(x,k=1,exterr=TRUE,sigdig=2,log=TRUE,i2i=TRUE,...){
-    peakfit_helper(x,k=k,exterr=exterr,sigdig=sigdig,log=log,i2i=i2i,...)
+peakfit.RbSr <- function(x,k=1,exterr=TRUE,sigdig=2,
+                         log=TRUE,i2i=TRUE,alpha=0.05,...){
+    peakfit_helper(x,k=k,exterr=exterr,sigdig=sigdig,
+                   log=log,i2i=i2i,alpha=alpha,...)
 }
 #' @rdname peakfit
 #' @export
-peakfit.LuHf <- function(x,k=1,exterr=TRUE,sigdig=2,log=TRUE,i2i=TRUE,...){
-    peakfit_helper(x,k=k,exterr=exterr,sigdig=sigdig,log=log,i2i=i2i,...)
+peakfit.LuHf <- function(x,k=1,exterr=TRUE,sigdig=2,
+                         log=TRUE,i2i=TRUE,alpha=0.05,...){
+    peakfit_helper(x,k=k,exterr=exterr,sigdig=sigdig,
+                   log=log,i2i=i2i,alpha=alpha,...)
 }
 #' @rdname peakfit
 #' @export
-peakfit.ThU <- function(x,k=1,exterr=FALSE,sigdig=2,log=TRUE,i2i=TRUE,...){
-    peakfit_helper(x,k=k,exterr=exterr,sigdig=sigdig,log=log,i2i=i2i,...)
+peakfit.ThU <- function(x,k=1,exterr=FALSE,sigdig=2,
+                        log=TRUE,i2i=TRUE,alpha=0.05,...){
+    peakfit_helper(x,k=k,exterr=exterr,sigdig=sigdig,
+                   log=log,i2i=i2i,alpha=alpha,...)
 }
 #' @rdname peakfit
 #' @export
-peakfit.UThHe <- function(x,k=1,sigdig=2,log=TRUE,...){
-    peakfit_helper(x,k=k,sigdig=sigdig,log=log,...)
+peakfit.UThHe <- function(x,k=1,sigdig=2,log=TRUE,alpha=0.05,...){
+    peakfit_helper(x,k=k,sigdig=sigdig,log=log,alpha=alpha,...)
 }
 peakfit_helper <- function(x,k=1,type=4,cutoff.76=1100,
                            cutoff.disc=c(-15,5),exterr=TRUE,sigdig=2,
-                           log=TRUE,i2i=FALSE,...){
+                           log=TRUE,i2i=FALSE,alpha=0.05,...){
     if (k<1) return(NULL)
     if (identical(k,'auto'))
-        k <- BIC_fit(x,5,log=log,type=type,cutoff.76=cutoff.76,cutoff.disc=cutoff.disc)
+        k <- BIC_fit(x,5,log=log,type=type, cutoff.76=cutoff.76,
+                     cutoff.disc=cutoff.disc)
     fit <- ages2peaks(x,k=k,log=log,i2i=i2i,type=type,
-                      cutoff.76=cutoff.76,cutoff.disc=cutoff.disc)
+                      cutoff.76=cutoff.76,cutoff.disc=cutoff.disc,
+                      alpha=alpha)
     if (exterr){
         if (identical(k,'min')) numpeaks <- 1
         else numpeaks <- k
         for (i in 1:numpeaks){
-            age.with.exterr <- add.exterr(x,fit$peaks[i],fit$peaks.err[i])
-            fit$peaks.err[i] <- age.with.exterr[2]
+            age.with.exterr <- add.exterr(x,fit$peaks['t',i],fit$peaks['s[t]',i])
+            fit$peaks['s[t]',i] <- age.with.exterr[2]
+            fit$peaks['ci[t]',i] <- fit$tfact*fit$peaks['s[t]',i]
         }
     }
     fit$legend <- peaks2legend(fit,sigdig=sigdig,k=k)
@@ -170,7 +212,8 @@ peakfit_helper <- function(x,k=1,type=4,cutoff.76=1100,
 }
 
 ages2peaks <- function(x,k=1,type=4,cutoff.76=1100,
-                       cutoff.disc=c(-15,5),log=TRUE,i2i=FALSE){
+                       cutoff.disc=c(-15,5),log=TRUE,i2i=FALSE,
+                       alpha=0.05){
     if (hasClass(x,'UPb')){
         tt <- filter.UPb.ages(x,type,cutoff.76,
                               cutoff.disc,exterr=FALSE)
@@ -193,7 +236,7 @@ ages2peaks <- function(x,k=1,type=4,cutoff.76=1100,
     } else if (hasClass(x,'ThU')){
         tt <- ThU.age(x,exterr=FALSE,i2i=i2i)
     }
-    peakfit.default(tt,k=k,log=log)
+    peakfit.default(tt,k=k,log=log,alpha=alpha)
 }
 
 get.peakfit.covmat <- function(k,pii,piu,aiu,biu){
@@ -246,22 +289,24 @@ get.props.err <- function(E){
 peaks2legend <- function(fit,sigdig=2,k=NULL){
     if (identical(k,'min')) return(min_age_to_legend(fit,sigdig))
     out <- NULL
-    for (i in 1:length(fit$peaks)){
-        rounded.age <- roundit(fit$peaks[i],fit$peaks.err[i],sigdig=sigdig)
-        rounded.prop <- roundit(fit$props[i],fit$props.err[i],sigdig=sigdig)
-        line <- paste0('Peak ',i,': ',rounded.age[1],'\u00B1',
-                       rounded.age[2],' (',100*rounded.prop[1],'\u00B1',
-                       100*rounded.prop[2],'%)')
+    for (i in 1:ncol(fit$peaks)){
+        rounded.age <- roundit(fit$peaks[1,i],fit$peaks[2:3,i],sigdig=sigdig)
+        line <- paste0('Peak ',i,': ',rounded.age[1],' \u00B1 ',
+                       rounded.age[2],' | ',rounded.age[3])
+        if (k>1){
+            rounded.prop <- roundit(fit$props[1,i],fit$props[2,i],sigdig=sigdig)
+            line <- paste0(line,' (',100*rounded.prop[1],'%)')
+        }
         out <- c(out,line)
     }
     out
 }
 min_age_to_legend <- function(fit,sigdig=2){
-    rounded.age <- roundit(fit$peaks,fit$peaks.err,sigdig=sigdig)
-    paste0('Minimum: ',rounded.age[1],'+/-',rounded.age[2])
+    rounded.age <- roundit(fit$peaks[1],fit$peaks[2:3],sigdig=sigdig)
+    paste0('Minimum: ',rounded.age[1],'\u00B1',rounded.age[2],' | ',rounded.age[3])
 }
 
-normal.mixtures <- function(x,k,sigdig=2,...){
+normal.mixtures <- function(x,k,sigdig=2,alpha=0.05,...){
     zu <- x[,1]
     su <- x[,2]
     xu <- 1/su
@@ -302,15 +347,17 @@ normal.mixtures <- function(x,k,sigdig=2,...){
         biu[,i] <- -(1-(yu-betai[i]*xu)^2)*xu^2
     }
     E <- get.peakfit.covmat(k,pii,piu,aiu,biu)
-    peaks.err <- sqrt(diag(E)[k:(2*k-1)])
-    props.err <- get.props.err(E)
-    out <- list(L=L,peaks=betai,props=pii,
-                peaks.err=peaks.err,props.err=props.err)
+    out <- format.peaks(peaks=betai,
+                        peaks.err=sqrt(diag(E)[k:(2*k-1)]),
+                        props=pii,
+                        props.err=get.props.err(E),
+                        df=n-2*k+1,alpha=alpha)
+    out$L <- L
     out$legend <- peaks2legend(out,sigdig=sigdig,k=k)
     out
 }
 
-binomial.mixtures <- function(x,k,exterr=TRUE,...){
+binomial.mixtures <- function(x,k,exterr=TRUE,alpha=0.05,...){
     yu <- x$x[,'Ns']
     mu <- x$x[,'Ns'] + x$x[,'Ni']
     NsNi <- (x$x[,'Ns']+0.5)/(x$x[,'Ni']+0.5)
@@ -348,9 +395,31 @@ binomial.mixtures <- function(x,k,exterr=TRUE,...){
     E <- get.peakfit.covmat(k,pii,piu,aiu,biu)
     beta.var <- diag(E)[k:(2*k-1)]
     pe <- theta2age(x,thetai,beta.var,exterr)
-    props.err <- get.props.err(E)
-    list(L=L,peaks=pe$peaks,props=pii,
-         peaks.err=pe$peaks.err,props.err=props.err)
+    out <- format.peaks(peaks=pe$peaks,
+                        peaks.err=pe$peaks.err,
+                        props=pii,
+                        props.err=get.props.err(E),
+                        df=n-2*k+1,alpha=alpha)
+    out$L <- L
+    out
+}
+
+format.peaks <- function(peaks,peaks.err,props,props.err,df,alpha=0.05){
+    out <- list()
+    k <- length(peaks)
+    out$tfact <- stats::qt(1-alpha/2,df)
+    out$peaks <- matrix(0,3,k)
+    colnames(out$peaks) <- 1:k
+    rownames(out$peaks) <- c('t','s[t]','ci[t]')
+    out$peaks['t',] <- peaks
+    out$peaks['s[t]',] <- peaks.err
+    out$peaks['ci[t]',] <- out$tfact*out$peaks['s[t]',]
+    out$props <- matrix(0,2,k)
+    colnames(out$props) <- 1:k
+    rownames(out$props) <- c('p','s[p]')
+    out$props['p',] <- props
+    out$props['s[p]',] <- props.err
+    out
 }
 
 theta2age <- function(x,theta,beta.var,exterr=TRUE){
@@ -377,23 +446,26 @@ BIC_fit <- function(x,max.k,type=4,cutoff.76=1100,
                     cutoff.disc=c(-15,5),exterr=TRUE,...){
     n <- length(x)
     BIC <- Inf
-    for (k in 1:max.k){
-        fit <- peakfit(x,k,type=type,cutoff.76=cutoff.76,
-                       cutoff.disc=cutoff.disc,exterr=exterr,...)
-        p <- 2*k-1
-        newBIC <- -2*fit$L+p*log(n)
-        if (newBIC<BIC) {
-            BIC <- newBIC
-        } else {
-            k <- k-1
-            break
+    out <- tryCatch({
+        for (k in 1:max.k){
+            fit <- peakfit(x,k,type=type,cutoff.76=cutoff.76,
+                           cutoff.disc=cutoff.disc,exterr=exterr,...)
+            p <- 2*k-1
+            newBIC <- -2*fit$L+p*log(n)
+            if (newBIC<BIC) {
+                BIC <- newBIC
+            } else {
+                return(k-1)
+            }
         }
-    }
-    k
+    },error = function(e){
+        return(k-1)
+    })
+    out
 }
 
 # Simple 3-parameter Normal model (Section 6.11 of Galbraith, 2005)
-min_age_model <- function(zs,sigdig=2){
+min_age_model <- function(zs,sigdig=2,alpha=0.05){
     z <- zs[,1]
     mu <- seq(min(z),max(z),length.out=100)
     sigma <- seq(stats::sd(z)/10,2*stats::sd(z),length.out=10)
@@ -414,8 +486,15 @@ min_age_model <- function(zs,sigdig=2){
     }
     H <- stats::optimHess(fit,get.minage.L,zs=zs)
     E <- solve(H)
-    out <- list(L=L,peaks=fit[1],
-                peaks.err=sqrt(E[1,1]),props.err=sqrt(E[3,3]))
+    out <- list()
+    out$L <- L
+    out$peaks <- matrix(0,3,1)
+    rownames(out$peaks) <- c('t','s[t]','ci[t]')
+    df <- length(z)-3
+    out$tfact <- stats::qt(1-alpha/2,df)
+    out$peaks['t',] <- fit[1]
+    out$peaks['s[t]',] <- sqrt(E[1,1])
+    out$peaks['ci[t]',] <- out$tfact*sqrt(E[1,1])
     out
 }
 
