@@ -14,15 +14,20 @@
 #'     \code{RbSr}, \code{LuHf}, \code{ThU}, \code{fissiontracks} or
 #'     \code{UThHe}
 #' @param ... optional arguments
-#' @return if \code{PLOT=FALSE}, returns a list with the following
-#'     items:
-#'
+#' @return returns a list with the following items:
 #' \describe{
-#' \item{mean}{a two element vector with the weighted mean and its
-#' standard error.}
+#' \item{mean}{a three element vector with:
 #'
-#' \item{disp}{a two element vector with the (over)dispersion and its
-#' standard error.}
+#' \code{x}: the weighted mean
+#'
+#' \code{s[x]}: the estimated analytical uncertainty of \code{x}
+#'
+#' \code{ci[x]}: the \eqn{100(1-\alpha/2)\%} confidence interval for
+#' \code{x} given the appropriate degrees of freedom
+#' }
+#'
+#' \item{disp}{a two element vector with the (over)dispersion the
+#' corresponding \eqn{100(1-\alpha/2)\%} confidence interval.}
 #'
 #' \item{mswd}{the Mean Square of the Weighted Deviates
 #' (a.k.a. `reduced Chi-square' statistic)}
@@ -31,8 +36,16 @@
 #' of freedom, testing the null hypothesis that the underlying
 #' population is not overdispersed.}
 #'
+#' \item{df}{the degrees of freedom for the Chi-square test}
+#'
+#' \item{tfact}{the \eqn{100(1-\alpha/2)} percentile of a
+#' t-distribution with \code{df} degrees of freedom}
+#'
 #' \item{valid}{vector of logical flags indicating which steps are
 #' included into the weighted mean calculation}
+#'
+#' \item{plotpar}{list of plot parameters for the weighted mean
+#' diagram}
 #' }
 #' @rdname weightedmean
 #' @export
@@ -69,14 +82,36 @@ weightedmean.default <- function(x,detect.outliers=TRUE,plot=TRUE,
                 break
         }
     }
-    fit <- get.weightedmean(X,sX,valid)
+    fit <- get.weightedmean(X,sX,valid=valid,alpha=alpha)
+    out <- fit
+    out$mean <- rep(NA,3)
+    out$disp <- rep(NA,2)
+    names(out$mean) <- c('x','s[x]','ci[x]')
+    names(out$disp) <- c('s','ci')
+    if (out$df>0) out$tfact <- stats::qt(1-alpha/2,out$df)
+    else out$tfact <- NA
+    out$mean[c('x','s[x]')] <- fit$mean[1:2]
+    out$mean['ci[x]'] <- out$tfact*out$mean['s[x]']
+    out$disp['s'] <- fit$disp
+    out$disp['ci'] <- stats::qnorm(1-alpha/2)*fit$disp
+    ns <- length(X)
+    out$plotpar <-
+        list(mean=list(x=c(0,ns+1),
+                       y=rep(out$mean['x'],2)),
+             rect=list(x=c(0,ns+1,ns+1,0),
+                       y=c(rep(out$mean['x']+out$mean['ci[x]'],2),
+                           rep(out$mean['x']-out$mean['ci[x]'],2))),
+             dash1=list(x=c(0,ns+1),
+                        y=rep(out$mean['x']+out$disp['ci'],2)),
+             dash2=list(x=c(0,ns+1),
+                        y=rep(out$mean['x']-out$disp['ci'],2))
+             )
     if (plot){
-        plot_weightedmean(X,sX,fit,rect.col=rect.col,
+        plot_weightedmean(X,sX,out,rect.col=rect.col,
                           outlier.col=outlier.col,sigdig=sigdig,
                           alpha=alpha,...)
-    } else {
-        return(fit)
     }
+    out
 }
 #' @param type scalar indicating whether to plot the
 #'     \eqn{^{207}}Pb/\eqn{^{235}}U age (\code{type}=1), the
@@ -161,8 +196,7 @@ weightedmean.ThU <- function(x,detect.outliers=TRUE,plot=TRUE,
                              alpha=0.05,i2i=TRUE,...){
     weightedmean_helper(x,detect.outliers=detect.outliers,plot=plot,
                         rect.col=rect.col,outlier.col=outlier.col,
-                        sigdig=sigdig,alpha=alpha,exterr=FALSE,
-                        i2i=i2i,...)
+                        sigdig=sigdig,alpha=alpha,i2i=i2i,...)
 }
 #' @rdname weightedmean
 #' @export
@@ -224,9 +258,10 @@ weightedmean.LuHf <- function(x,detect.outliers=TRUE,plot=TRUE,
 weightedmean.UThHe <- function(x,detect.outliers=TRUE,plot=TRUE,
                                rect.col=rgb(0,1,0,0.5),
                                outlier.col=rgb(0,1,1,0.5),
-                               sigdig=2,alpha=0.05,exterr=TRUE,...){
+                               sigdig=2,alpha=0.05,...){
     tt <- UThHe.age(x)
-    fit <- weightedmean.default(tt,detect.outliers=detect.outliers,plot=FALSE,...)
+    fit <- weightedmean.default(tt,detect.outliers=detect.outliers,
+                                alpha=alpha,plot=FALSE,...)
     if (plot){
         plot_weightedmean(tt[,1],tt[,2],fit,rect.col=rect.col,
                           outlier.col=outlier.col,sigdig=sigdig,
@@ -243,9 +278,10 @@ weightedmean.fissiontracks <- function(x,detect.outliers=TRUE,plot=TRUE,
                                        sigdig=2,alpha=0.05,exterr=TRUE,...){
     tt <- fissiontrack.age(x,exterr=FALSE)
     # calculated weighted mean age ignoring zeta and rhoD uncertainties
-    fit <- weightedmean.default(tt,detect.outliers=detect.outliers,plot=FALSE,...)
+    fit <- weightedmean.default(tt,detect.outliers=detect.outliers,
+                                alpha=alpha,plot=FALSE,...)
+    out <- fit
     if (exterr){
-        stt2 <- (fit$mean[2]/fit$mean[1])^2
         if (x$format==1) {
             rhoD <- x$rhoD
             zeta <- x$zeta
@@ -256,22 +292,27 @@ weightedmean.fissiontracks <- function(x,detect.outliers=TRUE,plot=TRUE,
             rhoD <- c(1,0)
             zeta <- c(1,0)
         }
-        fit$mean[2] <- fit$mean[1] *
-            sqrt( stt2 + (rhoD[2]/rhoD[1])^2 + (zeta[2]/zeta[1])^2 )
+        out$mean['s[x]'] <- fit$mean['x']*
+            sqrt( (fit$mean['s[x]']/fit$mean['x'])^2 +
+                  (rhoD[2]/rhoD[1])^2 +
+                  (zeta[2]/zeta[1])^2
+                )
+        out$mean['ci[x]'] <- fit$tfact*out$mean['s[x]']
     }
     if (plot){
-        plot_weightedmean(tt[,1],tt[,2],fit,rect.col=rect.col,
+        plot_weightedmean(tt[,1],tt[,2],out,rect.col=rect.col,
                           outlier.col=outlier.col,sigdig=sigdig,
                           alpha=alpha)
-    } else {
-        return(fit)
     }
+    out
 }
 weightedmean_helper <- function(x,detect.outliers=TRUE,plot=TRUE,
-                                rect.col=grDevices::rgb(0,1,0,0.5),type=4,
-                                cutoff.76=1100,cutoff.disc=c(-15,5),
-                                outlier.col=grDevices::rgb(0,1,1,0.5), sigdig=2,
-                                alpha=0.05,exterr=TRUE,i2i=FALSE,...){
+                                rect.col=grDevices::rgb(0,1,0,0.5),
+                                type=4,cutoff.76=1100,
+                                cutoff.disc=c(-15,5),
+                                outlier.col=grDevices::rgb(0,1,1,0.5),
+                                sigdig=2,alpha=0.05,exterr=TRUE,
+                                i2i=FALSE,...){
     if (hasClass(x,'UPb')){
         tt <- filter.UPb.ages(x,type=type,cutoff.76=cutoff.76,
                               cutoff.disc=cutoff.disc,exterr=FALSE)
@@ -279,6 +320,7 @@ weightedmean_helper <- function(x,detect.outliers=TRUE,plot=TRUE,
         tt <- PbPb.age(x,exterr=FALSE,i2i=i2i)
     } else if (hasClass(x,'ThU')){
         tt <- ThU.age(x,exterr=FALSE,i2i=i2i)
+        exterr <- FALSE
     } else if (hasClass(x,'ArAr')){
         tt <- ArAr.age(x,jcu=FALSE,exterr=FALSE,i2i=i2i)
     } else if (hasClass(x,'ReOs')){
@@ -290,20 +332,24 @@ weightedmean_helper <- function(x,detect.outliers=TRUE,plot=TRUE,
     } else if (hasClass(x,'LuHf')){
         tt <- LuHf.age(x,exterr=FALSE,i2i=i2i)
     }
-    fit <- weightedmean.default(tt,detect.outliers=detect.outliers,plot=FALSE,...)
+    fit <- weightedmean.default(tt,detect.outliers=detect.outliers,
+                                alpha=alpha,plot=FALSE,...)
+    out <- fit
     if (exterr){
-        fit$mean <- add.exterr(x,tt=fit$mean[1],st=fit$mean[2],
-                               cutoff.76=cutoff.76,type=type)
+        out$mean[c('x','s[x]')] <-
+            add.exterr(x,tt=fit$mean[1],st=fit$mean[2],
+                       cutoff.76=cutoff.76,type=type)
+        out$mean['ci[x]'] <- out$tfact*out$mean['s[x]']
     }
     if (plot){
-        plot_weightedmean(tt[,1],tt[,2],fit,rect.col=rect.col,
-                          outlier.col=outlier.col,sigdig=sigdig,alpha=alpha)
-    } else {
-        return(fit)
+        plot_weightedmean(tt[,1],tt[,2],out,rect.col=rect.col,
+                          outlier.col=outlier.col,sigdig=sigdig,
+                          alpha=alpha)
     }
+    out
 }
 
-get.weightedmean <- function(X,sX,valid=TRUE,overdispersion=TRUE){
+get.weightedmean <- function(X,sX,valid=TRUE,alpha=0.05){
     out <- list()
     x <- X[valid]
     sx <- sX[valid]
@@ -326,10 +372,12 @@ get.weightedmean <- function(X,sX,valid=TRUE,overdispersion=TRUE){
             out$mean <<- c(fit$par,sqrt(covmat))
             out$disp <<- 0
         }, finally = {
-            df <- length(x)-1
             SS <- sum(((x-out$mean[1])/sx)^2)
-            out$mswd <- SS/df
-            out$p.value <- 1-stats::pchisq(SS,df)
+            # remove two degrees of freedom for mu and disp
+            out$df <- length(x)-2
+            # add one d.o.f. (disp) for homogeneity test
+            out$mswd <- SS/(out$df+1)
+            out$p.value <- 1-stats::pchisq(SS,out$df+1)
             out$valid <- valid
         })
     } else {
@@ -350,7 +398,8 @@ gr.weightedmean.disp <- function(MZ,X,sX){
     M <- MZ[1]
     Z <- MZ[2]
     dLL.dmu <- (X-M)/(sX^2+exp(Z))
-    dLL.dZ <- -0.5*exp(Z)/(sX^2+exp(Z)) + 0.5*(exp(Z)*(X-M)^2)/((sX^2+exp(Z))^2)
+    dLL.dZ <- -0.5*exp(Z)/(sX^2+exp(Z)) +
+        0.5*(exp(Z)*(X-M)^2)/((sX^2+exp(Z))^2)
     c(sum(dLL.dmu),sum(dLL.dZ))
 }
 
@@ -360,32 +409,36 @@ LL.weightedmean <- function(M,X,sX){
 }
 
 wtdmean.title <- function(fit,sigdig=2){
-    rounded.mean <- roundit(fit$mean[1],fit$mean[2],sigdig=sigdig)
-    line1 <- substitute('mean ='~a%+-%b~' (1'~sigma~')',
-                        list(a=rounded.mean[1], b=rounded.mean[2]))
+    rounded.mean <- roundit(fit$mean[1],fit$mean[2:3],sigdig=sigdig)
+    line1 <- substitute('mean ='~a%+-%b~'|'~c,
+                        list(a=rounded.mean[1],
+                             b=rounded.mean[2],
+                             c=rounded.mean[3]))
     line2 <- substitute('MSWD ='~a~', p('~chi^2*')='~b,
                         list(a=signif(fit$mswd,sigdig),
                              b=signif(fit$p.value,sigdig)))
-    if (fit$p.value < 0.05){ # only show when the data are overdispersed
-        line3 <- paste0('overdispersion = ',signif(fit$disp,sigdig))
-        graphics::mtext(line1,line=2)
-        graphics::mtext(line2,line=1)
-        graphics::mtext(line3,line=0)
-    } else {
-        graphics::mtext(line1,line=1)
-        graphics::mtext(line2,line=0)
-    }
+    line3 <- substitute('dispersion ='~a~'|'~b,
+                        list(a=signif(fit$disp['s'],sigdig),
+                             b=signif(fit$disp['ci'],sigdig)))
+    graphics::mtext(line1,line=2)
+    graphics::mtext(line2,line=1)
+    graphics::mtext(line3,line=0)
 }
 
-plot_weightedmean <- function(X,sX,fit,rect.col=grDevices::rgb(0,1,0,0.5),
-                              outlier.col=grDevices::rgb(0,1,1,0.5),sigdig=2,
-                              alpha=0.05){
+plot_weightedmean <- function(X,sX,fit,
+                              rect.col=grDevices::rgb(0,1,0,0.5),
+                              outlier.col=grDevices::rgb(0,1,1,0.5),
+                              sigdig=2,alpha=0.05){
     ns <- length(X)
     fact <- stats::qnorm(1-alpha/2)
     minX <- min(X-fact*sX,na.rm=TRUE)
     maxX <- max(X+fact*sX,na.rm=TRUE)
-    graphics::plot(c(0,ns+1),c(minX,maxX),type='n',axes=FALSE,xlab='N',ylab='')
-    graphics::lines(c(0,ns+1),c(fit$mean[1],fit$mean[1]))
+    graphics::plot(c(0,ns+1),c(minX,maxX),type='n',
+                   axes=FALSE,xlab='N',ylab='')
+    graphics::polygon(fit$plotpar$rect,col='gray80',border=NA)
+    graphics::lines(fit$plotpar$mean)
+    graphics::lines(fit$plotpar$dash1,lty=3)
+    graphics::lines(fit$plotpar$dash2,lty=3)
     graphics::axis(side=1,at=1:ns)
     graphics::axis(side=2)
     for (i in 1:ns){
@@ -402,7 +455,7 @@ plot_weightedmean <- function(X,sX,fit,rect.col=grDevices::rgb(0,1,0,0.5),
 # valid is a vector of logical flags indicating whether the corresponding
 # measurements have already been rejected or not
 chauvenet <- function(X,sX,valid){
-    fit <- get.weightedmean(X,sX,valid)
+    fit <- get.weightedmean(X,sX,valid=valid)
     mu <- fit$mean[1]
     sigma <- sqrt(fit$disp^2+sX^2)
     prob <- 2*(1-stats::pnorm(abs(X-mu),sd=sigma))
