@@ -9,15 +9,25 @@
 #'     uncertainties of the X-values, the Y-values, the analytical
 #'     uncertainties of the Y-values, and the correlation coefficients
 #'     of the X- and Y-values.
+#' @param alpha cutoff value for confidence intervals
 #' @return a four-element list of vectors containing:
 #'     \describe{
+#'
 #'     \item{a}{the intercept of the straight line fit and its
 #'     standard error}
-#'     \item{b}{the slope of the fit and its standard
-#'     error}
+#'
+#'     \item{b}{the slope of the fit and its standard error}
+#'
 #'     \item{cov.ab}{the covariance of the slope and intercept}
+#'
 #'     \item{mswd}{the mean square of the residuals (a.k.a
 #'     `reduced Chi-square') statistic}
+#'
+#'     \item{df}{degrees of freedom of the linear fit \eqn{(2n-2)}}
+#'
+#'     \item{p.value}{p-value of a Chi-square value with \code{df}
+#'     degrees of freedom}
+#'
 #'     }
 #' @references
 #' Titterington, D.M. and Halliday, A.N., 1979. On the fitting of
@@ -50,37 +60,38 @@
 #'        polygon(ell)
 #'    }
 #' @export
-york <- function(x){
+york <- function(x,alpha=0.05){
     colnames(x) <- c('X','sX','Y','sY','rXY')
     ab <- stats::lm(x[,'Y'] ~ x[,'X'])$coefficients # initial guess
     a <- ab[1]
     b <- ab[2]
+    if (is.na(x) | is.na(b)) stop('Cannot fit a straight line through these data')
     wX <- 1/x[,'sX']^2
     wY <- 1/x[,'sY']^2
     for (i in 1:50){ # 50 = maximum number of iterations
         bold <- b
-        alpha <- sqrt(wX*wY)
-        W <- wX*wY/(wX+b*b*wY-2*b*x[,'rXY']*alpha)
+        A <- sqrt(wX*wY)
+        W <- wX*wY/(wX+b*b*wY-2*b*x[,'rXY']*A)
         Xbar <- sum(W*x[,'X'],na.rm=TRUE)/sum(W,na.rm=TRUE)
         Ybar <- sum(W*x[,'Y'],na.rm=TRUE)/sum(W,na.rm=TRUE)
         U <- x[,'X']-Xbar
         V <- x[,'Y']-Ybar
-        beta <- W*(U/wY+b*V/wX-(b*U+V)*x[,'rXY']/alpha)
-        b <- sum(W*beta*V,na.rm=TRUE)/sum(W*beta*U,na.rm=TRUE)
+        B <- W*(U/wY+b*V/wX-(b*U+V)*x[,'rXY']/A)
+        b <- sum(W*B*V,na.rm=TRUE)/sum(W*B*U,na.rm=TRUE)
         if ((bold/b-1)^2 < 1e-15) break # convergence reached
     }
     a <- Ybar-b*Xbar
-    X <- Xbar + beta
+    X <- Xbar + B
     xbar <- sum(W*X,na.rm=TRUE)/sum(W,na.rm=TRUE)
     u <- X-xbar
     sb <- sqrt(1/sum(W*u^2,na.rm=TRUE))
     sa <- sqrt(1/sum(W,na.rm=TRUE)+(xbar*sb)^2)
-    out <- list()
+    out <- get.york.mswd(x,a,b)
     out$a <- c(a,sa)
     out$b <- c(b,sb)
     out$cov.ab <- -Xbar*sb^2
-    mswd <- get.york.mswd(x,a,b)
-    out <- c(out,mswd)
+    names(out$a) <- c('a','s[a]')
+    names(out$b) <- c('b','s[b]')
     out
 }
 
@@ -94,10 +105,10 @@ get.york.mswd <- function(x,a,b){
         if (!any(is.na(X)))
             X2 <- X2 + 0.5*X %*% solve(E) %*% t(X)
     }
-    df <- ns-2
     out <- list()
-    out$mswd <- as.numeric(X2/df)
-    out$p.value <- as.numeric(1-stats::pchisq(X2,df))
+    out$df <- ns-2
+    out$mswd <- as.numeric(X2/out$df)
+    out$p.value <- as.numeric(1-stats::pchisq(X2,out$df))
     out
 }
 
@@ -107,14 +118,14 @@ get.york.mswd <- function(x,a,b){
 get.york.xy <- function(x,a,b){
     wX <- 1/x[,'sX']^2
     wY <- 1/x[,'sY']^2
-    alpha <- sqrt(wX*wY)
-    W <- wX*wY/(wX+b*b*wY-2*b*x[,'rXY']*alpha)
+    A <- sqrt(wX*wY)
+    W <- wX*wY/(wX+b*b*wY-2*b*x[,'rXY']*A)
     Xbar <- sum(W*x[,'X'],na.rm=TRUE)/sum(W,na.rm=TRUE)
     Ybar <- a + b*Xbar
     U <- x[,'X']-Xbar
     V <- x[,'Y']-Ybar
-    beta <- W*(U/wY+b*V/wX-(b*U+V)*x[,'rXY']/alpha)
-    out <- cbind(Xbar+beta,Ybar+b*beta)
+    B <- W*(U/wY+b*V/wX-(b*U+V)*x[,'rXY']/A)
+    out <- cbind(Xbar+B,Ybar+b*B)
     out
 }
 
